#
# spec file for package kubectl-cnpg
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

%define directory_name cloudnative-pg

Name:           kubectl-cnpg
Version:        1.24.0
Release:        1.1
Summary:        Manage PostgreSQL clusters built using CloudNativePG
License:        Apache-2.0
URL:            https://github.com/cloudnative-pg/cloudnative-pg
Source:         %{directory_name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
CloudNativePG provides a plugin for kubectl to manage a cluster in Kubernetes.

Documentation is at:
https://cloudnative-pg.io/documentation/1.23/kubectl-plugin

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1 -n %{directory_name}-%{version}

%build
# hash will be shortened by COMMIT_HASH:0:8 later
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{directory_name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/cloudnative-pg/cloudnative-pg/pkg/versions.buildVersion=v%{version} \
   -X github.com/cloudnative-pg/cloudnative-pg/pkg/versions.buildCommit=${COMMIT_HASH:0:8} \
   -X github.com/cloudnative-pg/cloudnative-pg/pkg/versions.buildDate=${BUILD_DATE}" \
   -o bin/%{name} ./cmd/%{name}/

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%check

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.24.0:
  kubectl-plugin-related changes:
  * feat(plugin): `--control-plane` option with `install generate`
    (#5271)
  * fix(plugin): delete jobs with `destroy` command (#5298)
  * feat(plugin): enable customizing the remote dbname in
    subscriptions and publications (#5113)
  * feat(plugin): display `demotionToken` in `cnpg status` (#5149)
  * feat: Add plugin method to ScheduledBackup (#4424)
  * fix(plugin): handle errors during the `status` command
    execution (#4882)
  * feat(plugin): support color control via  flags and TTY
    detection (#4775)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.23.4:
  kubectl-plugin-related changes:
  * feat(plugin): `--control-plane` option with `install generate`
    (#5271)
  * fix(plugin): delete jobs with `destroy` command (#5298)
  * feat: update default PostgreSQL version to 16.4 (#5262)
* Tue Jul 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.23.3:
  Changes related to the kubectl plugin:
  * Properly handle errors during the status command execution.
  * Support TLS in the status command (#4915).
* Thu Jun 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.23.2:
  * Enhancements:
  - Enabled configuration of standby-sensitive parameters during
    recovery using a physical backup (#4564)
  - Enabled the configuration of the liveness probe timeout via
    the .spec.livenessProbeTimeout option (#4719)
  - cnpg plugin for kubectl:
  * Enhanced support for ANSI colors in the plugin by adding
    the --color option, which accepts always, never, and auto
    (default) as values (#4775)
  * The plugin is now available on Homebrew for macOS users
    (#4602)
  * Fixes:
  - Prevented fenced instances from entering an unnecessary loop
    and consuming all available CPU (#4625)
  - Resolved an issue where the instance manager on the primary
    would indefinitely wait for the instance to start after
    encountering a failure following a stop operation (#4434)
  - Fixed an issue where the interaction between
    hot_standby_feedback and managed cluster-level replication
    slots was preventing the autovacuum from operating correctly;
    this issue was causing disk space to remain occupied by dead
    tuples (#4811)
  - Fixed a panic in the backup controller that occurred when pod
    container statuses were missing (#4765)
  - Prevented unnecessary shutdown of the instance manager
    (#4670)
  - Prevented unnecessary reloads of PostgreSQL configuration
    when unchanged (#4531)
  - Prevented unnecessary reloads of the ident map by ensuring a
    consistent and unique method of writing its content (#4648)
  - Avoided conflicts during phase registration by patching the
    status of the resource instead of updating it (#4637)
  - Implemented a timeout when restarting PostgreSQL and lifting
    fencing (#4504)
  - Ensured that a replica cluster is restarted after promotion
    to properly set the archive mode (#4399)
  - Removed an unneeded concurrent keep-alive routine that was
    causing random failures in volume snapshot backups (#4768)
  - Ensured correct parsing of the additional rows field returned
    when the pgaudit.log_rows option was enabled, preventing
    audit logs from being incorrectly routed to the normal log
    stream (#4394)
  - cnpg plugin for kubectl:
  * Resolved an issue with listing PDBs using the cnpg status
    command (#4530)
  * Changes
    Default operand image set to PostgreSQL 16.3 (#4584)
    Removed all RBAC requirements on namespace objects (#4753)
* Wed May  8 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package kubectl-cnpg: plugin to manage PostgreSQL clusters
  built using CloudNativePG
